@@ -44,7 +44,7 @@ See the README file for an example usage of this module.
 """
 
 
-__version__ = "$Id: cloghandler.py 5500 2008-05-29 21:10:07Z lowell $"
+__version__ = "$Id: cloghandler.py 5651 2008-09-09 21:58:14Z lowell $"
 __author__ = "Lowell Alleman"
 __all__ = [
     "ConcurrentRotatingFileHandler",
@@ -55,7 +55,14 @@ import os
 import sys
 from random import randint
 from logging import Handler
-from logging.handlers import BaseRotatingHandler, codecs
+from logging.handlers import BaseRotatingHandler
+
+try:
+    import codecs
+except ImportError:
+    codecs = None
+
+
 
 # Question/TODO: Should we have a fallback mode if we can't load portalocker /
 # we should still be better off than with the standard RotattingFileHandler
